@@ -437,6 +437,7 @@ void NetWinInfoTestWM::testState_data()
     const QByteArray fullScreen       = QByteArrayLiteral("_NET_WM_STATE_FULLSCREEN");
     const QByteArray keepBelow        = QByteArrayLiteral("_NET_WM_STATE_BELOW");
     const QByteArray demandsAttention = QByteArrayLiteral("_NET_WM_STATE_DEMANDS_ATTENTION");
+    const QByteArray focused          = QByteArrayLiteral("_NET_WM_STATE_FOCUSED");
 
     QTest::newRow("modal")            << NET::States(NET::Modal)            << (QVector<QByteArray>() << modal);
     QTest::newRow("sticky")           << NET::States(NET::Sticky)           << (QVector<QByteArray>() << sticky);
@@ -445,13 +446,13 @@ void NetWinInfoTestWM::testState_data()
     QTest::newRow("shaded")           << NET::States(NET::Shaded)           << (QVector<QByteArray>() << shaded);
     QTest::newRow("skipTaskbar")      << NET::States(NET::SkipTaskbar)      << (QVector<QByteArray>() << skipTaskbar);
     QTest::newRow("keepAbove")        << NET::States(NET::KeepAbove)        << (QVector<QByteArray>() << keepAbove << staysOnTop);
-    QTest::newRow("staysOnTop")       << NET::States(NET::StaysOnTop)       << (QVector<QByteArray>() << keepAbove << staysOnTop);
     QTest::newRow("skipPager")        << NET::States(NET::SkipPager)        << (QVector<QByteArray>() << skipPager);
     QTest::newRow("hidden")           << NET::States(NET::Hidden)           << (QVector<QByteArray>() << hidden);
     QTest::newRow("fullScreen")       << NET::States(NET::FullScreen)       << (QVector<QByteArray>() << fullScreen);
     QTest::newRow("keepBelow")        << NET::States(NET::KeepBelow)        << (QVector<QByteArray>() << keepBelow);
     QTest::newRow("demandsAttention") << NET::States(NET::DemandsAttention) << (QVector<QByteArray>() << demandsAttention);
     QTest::newRow("skipSwitcher")     << NET::States(NET::SkipSwitcher)     << (QVector<QByteArray>() << skipSwitcher);
+    QTest::newRow("focused")          << NET::States(NET::Focused)          << (QVector<QByteArray>() << focused);
 
     // TODO: it's possible to be keep above and below at the same time?!?
     QTest::newRow("all") << NET::States(NET::Modal |
@@ -465,11 +466,12 @@ void NetWinInfoTestWM::testState_data()
                                    NET::Hidden |
                                    NET::FullScreen |
                                    NET::DemandsAttention |
-                                   NET::SkipSwitcher)
+                                   NET::SkipSwitcher  |
+                                   NET::Focused)
                          << (QVector<QByteArray>() << modal << sticky << maxVert << maxHoriz
                              << shaded << skipTaskbar << keepAbove
                              << skipPager << hidden << fullScreen
-                             << keepBelow << demandsAttention << staysOnTop << skipSwitcher);
+                             << keepBelow << demandsAttention << staysOnTop << skipSwitcher << focused);
 }
 
 void NetWinInfoTestWM::testState()
